@@ -25,6 +25,7 @@ class Markets(Enum):
 
 class ISOBase:
     markets = []
+    status_homepage = None
 
     def _get_json(self, *args, **kwargs):
         r = requests.get(*args, **kwargs)
@@ -67,10 +68,10 @@ class ISOBase:
     def get_historical_supply(self, date):
         raise NotImplementedError()
 
-    def get_battery_today(self):
+    def get_storage_today(self):
         raise NotImplementedError()
 
-    def get_historical_battery(self, date):
+    def get_historical_storage(self, date):
         raise NotImplementedError()
 
     def _latest_lmp_from_today(self, market, locations):
@@ -113,11 +114,14 @@ class GridStatus:
         self.notes = notes
 
     def __repr__(self) -> str:
-        s = self.iso + "\n"
+        s = self.iso.name + "\n"
 
         s += "Time: %s \n" % str(self.time)
         s += "Status: %s \n" % self.status
 
+        if self.iso.status_homepage:
+            s += "Status Homepage: %s \n" % self.iso.status_homepage
+
         if self.reserves is not None:
             s += "Reserves: %.0f %s" % (self.reserves, self.unit)
 
