@@ -1,5 +1,3 @@
-from bdb import set_trace
-
 import pandas as pd
 
 from isodata import utils
@@ -11,6 +9,8 @@ class Ercot(ISOBase):
     iso_id = "ercot"
     default_timezone = "US/Central"
 
+    status_homepage = "https://www.ercot.com/gridmktinfo/dashboards/gridconditions"
+
     BASE = "https://www.ercot.com/api/1/services/read/dashboards"
 
     def get_latest_status(self):
@@ -27,7 +27,15 @@ class Ercot(ISOBase):
         if status == "normal":
             status = "Normal"
 
-        return GridStatus(time=time, status=status, reserves=reserves, iso=self.name)
+        notes = [r["current_condition"]["condition_note"]]
+
+        return GridStatus(
+            time=time,
+            status=status,
+            reserves=reserves,
+            iso=self,
+            notes=notes,
+        )
 
     def get_latest_fuel_mix(self):
         df = self.get_fuel_mix_today()
@@ -66,7 +74,7 @@ class Ercot(ISOBase):
         # says supports last 5 days, appears to support last two weeks
         # df = pd.read_html("https://www.ercot.com/content/cdr/html/20220810_actual_loads_of_forecast_zones.html")
         # even more historical data. up to month back i think: https://www.ercot.com/mp/data-products/data-product-details?id=NP6-346-CD
-        # ^ confusing to figure out how to parse though. use this endpoint: https://www.ercot.com/misapp/servlets/IceDocListJsonWS?reportTypeId=14836&_=1660840704920
+        # hourly load archives: https://www.ercot.com/gridinfo/load/load_hist
         url = self.BASE + "/loadForecastVsActual.json"
         r = self._get_json(url)
         df = pd.DataFrame(r[when]["data"])
@@ -114,11 +122,14 @@ class Ercot(ISOBase):
         # intrahour https://www.ercot.com/mp/data-products/data-product-details?id=NP3-562-CD
         # there are a few days of historical date for the forecast
         today = pd.Timestamp(pd.Timestamp.now(tz=self.default_timezone).date())
-        doc, publish_date = self._get_document(
+        doc_url, publish_date = self._get_document(
             report_type_id=12311,
             date=today,
+            constructed_name_contains="csv.zip",
         )
 
+        doc = pd.read_csv(doc_url, compression="zip")
+
         doc["Time"] = pd.to_datetime(
             doc["DeliveryDate"]
             + " "
@@ -135,22 +146,52 @@ class Ercot(ISOBase):
 
         return doc
 
-    def _get_document(self, report_type_id, date):
+    def get_historical_rtm_spp(self, year):
+        """Get Historical RTM Settlement Point Prices (SPPs) for each of the Hubs and Load Zones
+
+        Arguments:
+            year (int): year to get data for
+
+        Source: https://www.ercot.com/mp/data-products/data-product-details?id=NP6-785-ER
+        """
+        doc_url, date = self._get_document(
+            13061,
+            constructed_name_contains=f"{year}.zip",
+            verbose=True,
+        )
+
+        x = utils.get_zip_file(doc_url)
+        all_sheets = pd.read_excel(x, sheet_name=None)
+        df = pd.concat(all_sheets.values())
+        return df
+
+    def _get_document(
+        self,
+        report_type_id,
+        date=None,
+        constructed_name_contains=None,
+        verbose=False,
+    ):
         """Get document for a given report type id and date. If multiple document published return the latest"""
         url = f"https://www.ercot.com/misapp/servlets/IceDocListJsonWS?reportTypeId={report_type_id}"
         docs = self._get_json(url)["ListDocsByRptTypeRes"]["DocumentList"]
         match = []
         for d in docs:
-            if "csv" not in d["Document"]["FriendlyName"]:
-                continue
-
             doc_date = pd.Timestamp(d["Document"]["PublishDate"]).tz_convert(
                 self.default_timezone,
             )
 
             # check do we need to check if same timezone?
-            if doc_date.date() == date.date():
-                match.append((doc_date, d["Document"]["DocID"]))
+            if date and doc_date.date() != date.date():
+                continue
+
+            if (
+                constructed_name_contains
+                and constructed_name_contains not in d["Document"]["ConstructedName"]
+            ):
+                continue
+
+            match.append((doc_date, d["Document"]["DocID"]))
 
         if len(match) == 0:
             raise ValueError(
@@ -158,8 +199,8 @@ class Ercot(ISOBase):
             )
 
         doc = max(match, key=lambda x: x[0])
-        csv_url = f"https://www.ercot.com/misdownload/servlets/mirDownload?doclookupId={doc[1]}"
-        return pd.read_csv(csv_url, compression="zip"), doc[0]
+        url = f"https://www.ercot.com/misdownload/servlets/mirDownload?doclookupId={doc[1]}"
+        return url, doc[0]
 
     def _handle_data(self, df, columns):
         df["Time"] = (
@@ -170,3 +211,8 @@ class Ercot(ISOBase):
 
         cols_to_keep = ["Time"] + list(columns.keys())
         return df[cols_to_keep].rename(columns=columns)
+
+
+if __name__ == "__main__":
+    iso = Ercot()
+    iso.get_historical_rtm_spp(2020)
