@@ -1,6 +1,7 @@
 import pandas as pd
 from pandas import Timestamp
 
+from isodata import utils
 from isodata.base import FuelMix, ISOBase, Markets
 
 
@@ -170,6 +171,8 @@ class MISO(ISOBase):
             ]
         ]
 
+        data = utils.filter_lmp_locations(data, locations)
+
         return data
 
 
