@@ -1,6 +1,8 @@
-from datetime import datetime
+import io
+from zipfile import ZipFile
 
 import pandas as pd
+import requests
 
 import isodata
 from isodata.base import ISOBase, Markets
@@ -40,12 +42,12 @@ def make_availability_df():
         "get_demand_today",
         "get_forecast_today",
         "get_supply_today",
-        "get_battery_today",
+        "get_storage_today",
         "get_historical_fuel_mix",
         "get_historical_demand",
         "get_historical_forecast",
         "get_historical_supply",
-        "get_historical_battery",
+        "get_historical_storage",
     ]
 
     availability = {}
@@ -101,3 +103,11 @@ def filter_lmp_locations(data, locations: list):
         return data
 
     return data[data["Location"].isin(locations)]
+
+
+def get_zip_file(url):
+    # todo add retry logic
+    # todo does this need to be a with statement?
+    r = requests.get(url)
+    z = ZipFile(io.BytesIO(r.content))
+    return z.open(z.namelist()[0])
